@@ -80,7 +80,7 @@ OptimizerHyperband = R6Class("OptimizerHyperband",
     #' Creates a new instance of this [R6][R6::R6Class] class.
     initialize = function() {
       param_set = ps(
-        eta     = p_dbl(lower = 1.0001, tags = "required", default = 2),
+        eta     = p_dbl(lower = 1.0001, tags = "required"),
         sampler = p_uty(custom_check = function(x) check_r6(x, "Sampler", null.ok = TRUE)),
         repetitions = p_int(lower = 1L, default = 1, special_vals = list(Inf))
       )
