@@ -4,22 +4,12 @@
 #' @templateVar id successive_halving
 #'
 #' @description
-#' `OptimizerSuccessiveHalving` class that implements the successive halving
-#' algorithm (SHA). SHA randomly samples `n` candidate points and
-#' allocates a minimum budget (`r_min`) to all candidates. The candidates are
-#' raced down in stages to a single best candidate by repeatedly increasing the
-#' budget by a factor of `eta` and promoting only the best `1 / eta ` fraction
-#' to the next stage. This means promising points are allocated a higher budget
-#' overall and lower performing ones are discarded early on.
-#'
-#' #' The budget hyperparameter must be tagged with `"budget"` in the search space.
-#' The minimum budget (`r_min`) which is allocated in the base stage, is set by
-#' the lower bound of the budget parameter. The upper bound  defines the maximum
-#' budget (`r_max`) which is allocated to the candidates in the last stage. The
-#' number of stages is computed so that each candidate in base stage is
-#' allocated the minimum budget and the candidates in the last stage are not
-#' evaluated on more than the maximum budget. The following table is the stage
-#' layout for `eta = 2`, `r_min = 1` and `r_max = 8`.
+#' Optimizer using the Successive Halving Algorithm (SHA).
+#' SHA is initialized with the number of starting configurations `n`, the proportion of configurations discarded in each stage `eta`, and the minimum `r_min` and maximum `_max` budget of a single evaluation.
+#' The algorithm starts by sampling `n` random configurations and allocating the minimum budget `r_min` to them.
+#' The configurations are evaluated and `1 / eta` of the worst-performing configurations are discarded.
+#' The remaining configurations are promoted to the next stage and evaluated on a larger budget.
+#' The following table is the stage layout for `eta = 2`, `r_min = 1` and `r_max = 8`.
 #'
 #' | `i` | `n_i` | `r_i` |
 #' | --: | ----: | ----: |
@@ -28,35 +18,39 @@
 #' |   2 |     2 |     4 |
 #' |   3 |     1 |     8 |
 #'
-#' `i` is stage number, `n_i` is the number of configurations and `r_i` is the
-#' budget allocated to a single configuration.
+#' `i` is the stage number, `n_i` is the number of configurations and `r_i` is the budget allocated to a single configuration.
+#'
+#' The number of stages is calculated so that each stage consumes approximately the same budget.
+#' This sometimes results in the minimum budget having to be slightly adjusted by the algorithm.
+#'
+#' @section Resources:
+#' The [gallery](https://mlr-org.com/gallery-all-optimization.html) features a collection of case studies and demos about optimization.
+#'
+#'  * [Tune](https://mlr-org.com/gallery/series/2023-01-15-hyperband-xgboost/) the hyperparameters of XGBoost with Hyperband (Hyperband can be easily swapped with SHA).
+#'  * Use data [subsampling](https://mlr-org.com/gallery/series/2023-01-16-hyperband-subsampling/) and Hyperband to optimize a support vector machine.
+#'
+#' @template section_dictionary_optimizers
 #'
 #' @section Parameters:
 #' \describe{
 #' \item{`n`}{`integer(1)`\cr
-#' Number of points in base stage.}
+#'   Number of configurations in the base stage.}
 #' \item{`eta`}{`numeric(1)`\cr
-#' With every stage, the budget is increased by a factor of `eta`
-#' and only the best `1 / eta` points are promoted to the next stage.
-#' }
+#'   With every stage, the budget is increased by a factor of `eta` and only the best `1 / eta` configurations are promoted to the next stage.
+#'   Non-integer values are supported, but `eta` is not allowed to be less or equal to 1.}
 #' \item{`sampler`}{[paradox::Sampler]\cr
-#' Object defining how the samples of the parameter space should be drawn. The
-#' default is uniform sampling.
-#' }
+#'   Object defining how the samples of the parameter space should be drawn.
+#'   The default is uniform sampling.}
 #' \item{`repetitions`}{`integer(1)`\cr
-#' If `1` (default), optimization is stopped once all stages are evaluated.
-#' Otherwise, optimization is stopped after `repetitions` runs of SHA. The
-#' [bbotk::Terminator] might stop the optimization before all repetitions are
-#' executed.
-#' }
+#'   If `1` (default), optimization is stopped once all stages are evaluated.
+#'   Otherwise, optimization is stopped after `repetitions` runs of SHA.
+#'   The [bbotk::Terminator] might stop the optimization before all repetitions are executed.}
 #' \item{`adjust_minimum_budget`}{`logical(1)`\cr
-#' If `TRUE`, minimum budget is increased so that the last stage uses the
-#' maximum budget defined in the search space.
-#' }}
+#'   If `TRUE`, the minimum budget is increased so that the last stage uses the maximum budget defined in the search space.}
+#' }
 #'
 #' @section Archive:
-#' The [bbotk::Archive] holds the following additional columns that are specific
-#' to the successive halving algorithm:
+#' The [bbotk::Archive] holds the following additional columns that are specific to SHA:
 #'   * `stage` (`integer(1))`\cr
 #'     Stage index. Starts counting at 0.
 #'   * `repetition` (`integer(1))`\cr
@@ -183,3 +177,6 @@ OptimizerSuccessiveHalving = R6Class("OptimizerSuccessiveHalving",
     }
   )
 )
+
+#' @include aaa.R
+optimizers[["successive_halving"]] = OptimizerSuccessiveHalving
